@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    https://www.imagemagick.org/script/license.php
+    https://imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -54,7 +54,8 @@ extern MagickExport char
   *StringInfoToString(const StringInfo *),
   **StringToArgv(const char *,int *),
   *StringToken(const char *,char **),
-  **StringToList(const char *);
+  **StringToList(const char *),
+  **StringToStrings(const char *,size_t *);
 
 extern MagickExport const char
   *GetStringInfoName(const StringInfo *),
@@ -69,8 +70,8 @@ extern MagickExport int
 
 extern MagickExport MagickBooleanType
   ConcatenateString(char **,const char *),
-  IsStringTrue(const char *),
-  IsStringFalse(const char *),
+  IsStringTrue(const char *) magick_attribute((__pure__)),
+  IsStringFalse(const char *) magick_attribute((__pure__)),
   SubstituteString(char **,const char *,const char *);
 
 extern MagickExport size_t
